#!/usr/bin/python
import os
import shutil
import numpy as np

# Enter your calculated value for the minimal lattice constant 
aMin = 5.1
# Enter your calculated value for the maximal lattice constant
aMax = 5.7
# Enter a value for the stepwidth
step = 0.1
# Number of calculations
n = int(np.rint((aMax - aMin)/step)) + 1

for i in range(n):
   aLat = aMin + step * i
   print("Processing lattice constant %10.6f AA." % aLat)
   # Create directory
   dirname = str(aLat)
   if not os.path.exists(dirname):
     os.makedirs(dirname)
   # Change to directory        
   os.chdir(dirname)

   # Write geometry.in
   filename = "geometry.in"
   f = open(filename,'w')
   # The lattice
   f.write("%-14s %10.6f %10.6f %10.6f\n" 
         % ("lattice_vector",0.0,      0.5*aLat, 0.5*aLat))
   f.write("%-14s %10.6f %10.6f %10.6f\n" 
         % ("lattice_vector",0.5*aLat, 0.0,      0.5*aLat))
   f.write("%-14s %10.6f %10.6f %10.6f\n" 
         % ("lattice_vector",0.5*aLat, 0.5*aLat, 0.0))
   # The atoms
   f.write("%-14s %10.6f %10.6f %10.6f %2s\n" 
         % ("atom_frac",0.00, 0.00, 0.00,"Si"))
   f.write("%-14s %10.6f %10.6f %10.6f %2s\n" 
         % ("atom_frac",0.25, 0.25, 0.25,"Si"))
   # Close file
   f.close()

   # Copy the control file
   shutil.copyfile("../control.in","control.in")

   # Run FHI-aims on 2 processes
   os.system("mpirun -n 4 aims.x > aims.out")

   # Change back to former directory
   os.chdir("..")
